@@ -269,14 +269,12 @@ class Node(object):
         0.1
         0.2
         """
-        return self._model.getNodeParam(self._nodeid,
-                                        NodeParams.invertElev.value)
+        return self._model.getNodeParam(self._nodeid, NodeParams.invertElev.value)
 
     @invert_elevation.setter
     def invert_elevation(self, param):
         """Set Node Invert Elevation."""
-        self._model.setNodeParam(self._nodeid, NodeParams.invertElev.value,
-                                 param)
+        self._model.setNodeParam(self._nodeid, NodeParams.invertElev.value, param)
 
     @property
     def full_depth(self):
@@ -307,14 +305,12 @@ class Node(object):
         10
         50
         """
-        return self._model.getNodeParam(self._nodeid,
-                                        NodeParams.fullDepth.value)
+        return self._model.getNodeParam(self._nodeid, NodeParams.fullDepth.value)
 
     @full_depth.setter
     def full_depth(self, param):
         """Set Node Full Depth."""
-        self._model.setNodeParam(self._nodeid, NodeParams.fullDepth.value,
-                                 param)
+        self._model.setNodeParam(self._nodeid, NodeParams.fullDepth.value, param)
 
     @property
     def surcharge_depth(self):
@@ -345,14 +341,12 @@ class Node(object):
         10
         50
         """
-        return self._model.getNodeParam(self._nodeid,
-                                        NodeParams.surDepth.value)
+        return self._model.getNodeParam(self._nodeid, NodeParams.surDepth.value)
 
     @surcharge_depth.setter
     def surcharge_depth(self, param):
         """Set Node Surcharge Depth."""
-        self._model.setNodeParam(self._nodeid, NodeParams.surDepth.value,
-                                 param)
+        self._model.setNodeParam(self._nodeid, NodeParams.surDepth.value, param)
 
     @property
     def ponding_area(self):
@@ -383,14 +377,12 @@ class Node(object):
         0
         50
         """
-        return self._model.getNodeParam(self._nodeid,
-                                        NodeParams.pondedArea.value)
+        return self._model.getNodeParam(self._nodeid, NodeParams.pondedArea.value)
 
     @ponding_area.setter
     def ponding_area(self, param):
         """Set Node Ponding Area."""
-        self._model.setNodeParam(self._nodeid, NodeParams.pondedArea.value,
-                                 param)
+        self._model.setNodeParam(self._nodeid, NodeParams.pondedArea.value, param)
 
     @property
     def initial_depth(self):
@@ -421,14 +413,12 @@ class Node(object):
         0
         1
         """
-        return self._model.getNodeParam(self._nodeid,
-                                        NodeParams.initDepth.value)
+        return self._model.getNodeParam(self._nodeid, NodeParams.initDepth.value)
 
     @initial_depth.setter
     def initial_depth(self, param):
         """Set Node Initial Depth."""
-        self._model.setNodeParam(self._nodeid, NodeParams.initDepth.value,
-                                 param)
+        self._model.setNodeParam(self._nodeid, NodeParams.initDepth.value, param)
 
     @property
     def total_inflow(self):
@@ -455,8 +445,7 @@ class Node(object):
         1.9
         1.2
         """
-        return self._model.getNodeResult(self._nodeid,
-                                         NodeResults.totalinflow.value)
+        return self._model.getNodeResult(self._nodeid, NodeResults.totalinflow.value)
 
     @property
     def total_outflow(self):
@@ -483,8 +472,7 @@ class Node(object):
         1.9
         1.2
         """
-        return self._model.getNodeResult(self._nodeid,
-                                         NodeResults.outflow.value)
+        return self._model.getNodeResult(self._nodeid, NodeResults.outflow.value)
 
     @property
     def losses(self):
@@ -511,8 +499,7 @@ class Node(object):
         0.01
         0.01
         """
-        return self._model.getNodeResult(self._nodeid,
-                                         NodeResults.losses.value)
+        return self._model.getNodeResult(self._nodeid, NodeResults.losses.value)
 
     @property
     def volume(self):
@@ -539,8 +526,7 @@ class Node(object):
         1.9
         1.2
         """
-        return self._model.getNodeResult(self._nodeid,
-                                         NodeResults.newVolume.value)
+        return self._model.getNodeResult(self._nodeid, NodeResults.newVolume.value)
 
     @property
     def flooding(self):
@@ -567,8 +553,7 @@ class Node(object):
         0
         0
         """
-        return self._model.getNodeResult(self._nodeid,
-                                         NodeResults.overflow.value)
+        return self._model.getNodeResult(self._nodeid, NodeResults.overflow.value)
 
     @property
     def depth(self):
@@ -595,8 +580,7 @@ class Node(object):
         0.52
         0.49
         """
-        return self._model.getNodeResult(self._nodeid,
-                                         NodeResults.newDepth.value)
+        return self._model.getNodeResult(self._nodeid, NodeResults.newDepth.value)
 
     @property
     def head(self):
@@ -623,8 +607,7 @@ class Node(object):
         10.52
         10.49
         """
-        return self._model.getNodeResult(self._nodeid,
-                                         NodeResults.newHead.value)
+        return self._model.getNodeResult(self._nodeid, NodeResults.newHead.value)
 
     @property
     def lateral_inflow(self):
@@ -651,8 +634,7 @@ class Node(object):
         0.3
         0.4
         """
-        return self._model.getNodeResult(self._nodeid,
-                                         NodeResults.newLatFlow.value)
+        return self._model.getNodeResult(self._nodeid, NodeResults.newLatFlow.value)
 
     @property
     def hydraulic_retention_time(self):
@@ -665,8 +647,7 @@ class Node(object):
         :return: Parameter Value
         :rtype: float
         """
-        return self._model.getNodeResult(self._nodeid,
-                                         NodeResults.hyd_res_time.value)
+        return self._model.getNodeResult(self._nodeid, NodeResults.hyd_res_time.value)
 
     def generated_inflow(self, inflowrate):
         """
@@ -726,8 +707,9 @@ class Node(object):
         """
         out_dict = {}
         pollut_ids = self._model.getObjectIDList(ObjectType.POLLUT.value)
-        quality_array = self._model.getNodePollut(self._nodeid,
-                                                      NodePollut.nodeQual.value)
+        quality_array = self._model.getNodePollut(
+            self._nodeid, NodePollut.nodeQual.value
+        )
 
         for ind in range(len(pollut_ids)):
             out_dict[pollut_ids[ind]] = quality_array[ind]
@@ -738,7 +720,7 @@ class Node(object):
     def pollut_quality(self, args):
         """
         Set Current Node Water Quality Value
-        
+
         Examples:
 
         >>> from pyswmm import Simulation, Nodes
@@ -753,7 +735,7 @@ class Node(object):
         {'test-pollutant': 100.0}
         """
         pollutant_ID, pollutant_value = args
-        
+
         self._model.setNodePollut(self._nodeid, pollutant_ID, pollutant_value)
 
     @property
@@ -780,8 +762,9 @@ class Node(object):
         """
         out_dict = {}
         pollut_ids = self._model.getObjectIDList(ObjectType.POLLUT.value)
-        quality_array = self._model.getNodePollut(self._nodeid,
-                                                      NodePollut.inflowQual.value)
+        quality_array = self._model.getNodePollut(
+            self._nodeid, NodePollut.inflowQual.value
+        )
 
         for ind in range(len(pollut_ids)):
             out_dict[pollut_ids[ind]] = quality_array[ind]
@@ -812,8 +795,9 @@ class Node(object):
         """
         out_dict = {}
         pollut_ids = self._model.getObjectIDList(ObjectType.POLLUT.value)
-        quality_array = self._model.getNodePollut(self._nodeid,
-                                                      NodePollut.reactorQual.value)
+        quality_array = self._model.getNodePollut(
+            self._nodeid, NodePollut.reactorQual.value
+        )
 
         for ind in range(len(pollut_ids)):
             out_dict[pollut_ids[ind]] = quality_array[ind]
